from django.contrib.admin.widgets import AdminFileWidget
from django.conf import settings

from easy_thumbnails.files import get_thumbnailer


ADMIN_THUMBNAIL_SIZE = getattr(settings, 'IMAGE_CROPPING_THUMB_SIZE', (300, 300))
def thumbnail(image_path):
    thumbnailer = get_thumbnailer(image_path)
    thumbnail_options = {
        'detail': True,
        'size': ADMIN_THUMBNAIL_SIZE,
    }
    thumb = thumbnailer.get_thumbnail(thumbnail_options)
    return thumb.url


class ImageCropWidget(AdminFileWidget):
    def render(self, name, value, attrs=None):
        if not attrs:
            attrs = {}
        if value:
            attrs.update({
                'class': "crop-thumb",
                'data-thumbnail-url': thumbnail(value),
                'data-field-name': name,
                'data-org-width': value.width,
                'data-org-height': value.height,
            })
        return super(AdminFileWidget, self).render(name, value, attrs)

    class Media:
        js = (
            getattr(settings, 'JQUERY_URL',
                'https://ajax.googleapis.com/ajax/libs/jquery/1.5/jquery.min.js'),
            "image_cropping/jquery.imgareaselect.min.js",
            "image_cropping/image_cropping.js",
        )
        css= {'all' : ("image_cropping/imgareaselect-default.css",)}




from django.db import models
from django import forms
from .widgets import ImageCropWidget


class ImageCropField(models.ImageField):
    def formfield(self, *args, **kwargs):
        kwargs['widget'] = ImageCropWidget
        return super(ImageCropField, self).formfield(*args, **kwargs)

    def south_field_triple(self):
        """
        Return a suitable description of this field for South.
        """
        # We'll just introspect ourselves, since we inherit.
        from south.modelsinspector import introspector
        field_class = "django.db.models.fields.files.ImageField"
        args, kwargs = introspector(self)
        return (field_class, args, kwargs)


class ImageRatioField(models.CharField):
    def __init__(self, image_field, size, adapt_rotation=False):
        self.width, self.height = size.split('x')
        self.image_field = image_field
        self.adapt_rotation = adapt_rotation
        super(ImageRatioField, self).__init__(max_length=255, blank=True)

    def formfield(self, *args, **kwargs):
        kwargs['widget'] =  forms.TextInput(attrs={
            'data-width': int(self.width),
            'data-height': int(self.height),
            'data-image-field': self.image_field,
            'data-my-name': self.name,
            'data-adapt-rotation': str(self.adapt_rotation).lower(),
            'class': 'image-ratio',
        })
        return super(ImageRatioField, self).formfield(*args, **kwargs)

    def south_field_triple(self):
        """
        Return a suitable description of this field for South.
        """
        # We'll just introspect ourselves, since we inherit.
        from south.modelsinspector import introspector
        field_class = "django.db.models.fields.CharField"
        args, kwargs = introspector(self)
        return (field_class, args, kwargs)



from distutils.core import setup
from setuptools import setup, find_packages

setup(name = "django-image-cropping",
    version = "0.2.1",
    description = "A reusable app for cropping images easily and non-destructively in Django",
    long_description=open('README.rst').read(),
    author = "jonasvp",
    author_email = "jvp@jonasundderwolf.de",
    url = "http://github.com/jonasundderwolf/django-image-cropping",
    #Name the folder where your packages live:
    #(If you have other packages (dirs) or modules (py files) then
    #put them into the package directory - they will be found
    #recursively.)
    packages = find_packages(),
    include_package_data=True,
    install_requires = [
        'docutils',
        'PIL',
        'easy_thumbnails',
    ],
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)



def crop_corners(image, box=None, **kwargs):
    """
    Crop corners to the selection defined by image_cropping
    """

    if box:
        values = [int(x) for x in box.split(',')]
        box = (
            int(values[0]),
            int(values[1]),
            int(values[2]),
            int(values[3]),
        )
        image = image.crop(box)

    return image

